What's new
**********

.. contents::
   :local:
   :backlinks: none
   :depth: 1

v0.2.0 (2021-01-18)
===================

- Increase test coverage to 100% (:pull:`12`).
- Port code from :mod:`message_ix.reporting` (:pull:`11`).
- Add :mod:`.compat.pyam`.
- Add a `name` parameter to :func:`.load_file`.

v0.1.0 (2021-01-10)
===================

- Initial code port from :mod:`ixmp.reporting`.
